@@ -4,6 +4,7 @@ mod dynamodb;
 mod mysql;
 mod postgres;
 mod redis;
+mod redshift;
 mod snowflake;
 mod sqlite;
 mod tidb;
@@ -15,6 +16,7 @@ pub use dynamodb::DynamoDB;
 pub use mysql::MySQL;
 pub use postgres::Postgres;
 pub use redis::Redis;
+pub use redshift::Redshift;
 pub use snowflake::Snowflake;
 pub use sqlite::SQLite;
 pub use tidb::TiDB;
